from unittest import TestCase
from skale import Skale, NodeManager, Token, BaseContract
import unittest


class ManagerContractTest(TestCase):
    def setUp(self):
        self.skale = Skale('51.0.1.99', 8546)

    def test_create_node(self):
        pass
        # todo: create node and save config here

    def test_get_node(self):
        node_id = 11 # todo: get node_id from the config
        node = self.skale.manager().get_node(node_id)
        print(node)
        # todo: add check



if __name__ == '__main__':
    unittest.main()



from time import sleep
from skale import Skale, EventListener

def handler(event):
  print('Event:')
  print(event)

if __name__ == '__main__':
  skale = Skale('51.0.1.99', 8546)

  event = skale.manager().contract.events.NodeCreated
  listener = EventListener(event, handler, 5)
  listener.run()

  port = 28
  ip = '15.24.32.132'
  account = skale.web3.eth.accounts[0]
  res = skale.manager().create_node(ip, port, account)

  sleep(5)
  receipt = skale.web3.eth.getTransaction(res)
  print("Receipt:")
  print(receipt)



from unittest import TestCase
from skale import Skale, NodeManager, Token, BaseContract
import unittest


class Web3Test(TestCase):
    def setUp(self):
        self.skale = Skale('51.0.1.99', 8546)

    def test_connection(self):
        self.assertTrue(self.skale.web3.isConnected(), 'not connected to node')

    def test_contracts_instances(self):
        manager_contract = self.skale.manager()
        self.assertIsInstance(manager_contract, NodeManager)

        token_contract = self.skale.token()
        self.assertIsInstance(token_contract, Token)

        self.assertIsInstance(token_contract, BaseContract)
        self.assertIsInstance(manager_contract, BaseContract)


if __name__ == '__main__':
    unittest.main()
